==> iydon-2023.3.0.tar.gz: iydon-2023.3.0/README.md <==
<div align="center">
  <a href="https://github.com/iydon/iydon">
    🔵⬜🟦⬜🟦<br />
    ⬜⬜🟦⬜🟦<br />
    🟦⬜🟦🟦🟦<br />
    🟦⬜⬜⬜🟦<br />
    🟦⬜🟦🟦🟦<br />
  </a>

  <h3 align="center">Iydon (梁钰栋 in Chinese)</h3>

  <p align="center">
    <a href="https://www.iydon.top">
      <img src="https://img.shields.io/static/v1?label=Blog&message=iydon.top&color=brightgreen" />
    </a>
    ·
    <a href="https://github.com/iydon">
      <img src="https://img.shields.io/static/v1?label=GitHub&message=iydon&color=green" />
    </a>
    ·
    <a href="mailto:liangiydon@gmail.com">
      <img src="https://img.shields.io/static/v1?label=Gmail&message=liangiydon&color=yellowgreen" />
    </a>
    ·
    <a href="https://steamcommunity.com/id/iydon">
      <img src="https://img.shields.io/static/v1?label=Steam&message=iydon&color=yellow" />
    </a>
    ·
    <img src="https://visitor-badge.glitch.me/badge?page_id=iydon&right_color=orange&left_text=Visitors" />
    ·
    <img src="https://img.shields.io/static/v1?label=WeChat&message=liangiydon&color=red" />
  </p>
</div>



<details>
  <summary><strong>GitHub Statistics</strong></summary>
  <img src="https://github-readme-stats.vercel.app/api?username=iydon&count_private=true&show_icons=true&include_all_commits=true&theme=graywhite" />
</details>



<details>
  <summary><strong>Code Statistics</strong></summary>
  <pre><code>
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
 Language            Files        Lines         Code     Comments       Blanks
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
 Autoconf                9           45           36            0            9
 BASH                   32           98           34           32           32
 Batch                   7          343          289            3           51
 C                      35        4,264        2,477        1,053          734
 C Header               46        3,370        2,351          485          534
 C++                    13          611          462           40          109
 CSS                     6          493          480           12            1
 Cython                  1           16            7            5            4
 Dockerfile              3          215           95          100           20
 Forge Config            2           38           38            0            0
 FORTRAN Modern          2          201          164            0           37
 Go                      2          140          118            0           22
 INI                     1            6            6            0            0
 JavaScript              2            4            4            0            0
 JSON                   79       21,919       21,917            0            2
 Julia                   2          120          105            0           15
 M4                      2        1,069          927            0          142
 MATLAB                155        6,266        4,650        1,017          599
 Makefile               70        1,301          910           79          312
 Python                831       87,567       75,254        2,112       10,201
 R                       5          256          215            6           35
 ReStructuredText       21        1,046          705            0          341
 Rust                  144        9,551        8,301          259          991
 Shell                   9          158           91           38           29
 SQL                    22        8,027        7,823          118           86
 SVG                     6          968          883            1           84
 TeX Class              26       14,091       10,548        2,413        1,130
 TeX Definition          3          207          195           12            0
 TeX                   676      328,270      178,952        3,421      145,897
 Plain Text             66      181,661            0      179,586        2,075
 TOML                   15          435          376            7           52
 XML                     1            7            7            0            0
 YAML                   93       37,661       35,816        1,147          698
───────────────────────────────────────────────────────────────────────────────
 HTML                   32        2,626        2,231          322           73
 |- CSS                  6          123          122            0            1
 |- JavaScript          10          530          457           11           62
 (Total)                          3,279        2,810          333          136
───────────────────────────────────────────────────────────────────────────────
 Jupyter Notebooks      11          658          324          270           64
 |- Markdown             7          288            0          259           29
 |- Python              10          370          324           11           35
 (Total)                          1,316          648          540          128
───────────────────────────────────────────────────────────────────────────────
 Markdown              375       27,397            0       20,914        6,483
 |- C                    1            7            6            0            1
 |- C++                  2           78           63            2           13
 |- HTML                 2           66           66            0            0
 |- JSON                 2        1,096        1,096            0            0
 |- MATLAB               1           62           28           29            5
 |- Markdown             1           51            0           50            1
 |- Python              36        2,017        1,621           82          314
 |- R                    2          214          178           36            0
 |- Rust                 2          269          237            6           26
 |- Shell               23        1,027          979            0           48
 |- SQL                  1            2            2            0            0
 |- TeX                  2           42           35            0            7
 |- TOML                 1           13           11            0            2
 |- XML                  1            8            8            0            0
 |- YAML                 7          263          234           17           12
 (Total)                         32,612        4,564       21,136        6,912
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
 Total               2,805      747,631      362,258      213,955      171,418
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
  </code></pre>
</details>

==> iydon-2023.4.tar.gz: iydon-2023.4/README.md <==
<div align="center">
  <a href="https://github.com/iydon/iydon">
    🔵⬜🟦⬜🟦<br />
    ⬜⬜🟦⬜🟦<br />
    🟦⬜🟦🟦🟦<br />
    🟦⬜⬜⬜🟦<br />
    🟦⬜🟦🟦🟦<br />
  </a>

  <h3 align="center">Iydon (梁钰栋 in Chinese)</h3>

  <p align="center">
    <a href="https://www.iydon.top">
      <img src="https://img.shields.io/static/v1?label=Blog&message=iydon.top&color=brightgreen" />
    </a>
    ·
    <a href="https://github.com/iydon">
      <img src="https://img.shields.io/static/v1?label=GitHub&message=iydon&color=green" />
    </a>
    ·
    <a href="mailto:liangiydon@gmail.com">
      <img src="https://img.shields.io/static/v1?label=Gmail&message=liangiydon&color=yellowgreen" />
    </a>
    ·
    <a href="https://steamcommunity.com/id/iydon">
      <img src="https://img.shields.io/static/v1?label=Steam&message=iydon&color=yellow" />
    </a>
    ·
    <img src="https://visitor-badge.glitch.me/badge?page_id=iydon&right_color=orange&left_text=Visitors" />
    ·
    <img src="https://img.shields.io/static/v1?label=WeChat&message=liangiydon&color=red" />
  </p>
</div>



<details>
  <summary><strong>GitHub Statistics</strong></summary>
  <img src="https://github-readme-stats.vercel.app/api?username=iydon&count_private=true&show_icons=true&include_all_commits=true&theme=graywhite" />
</details>



<details>
  <summary><strong>Code Statistics</strong></summary>
  <pre><code>
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
 Language            Files        Lines         Code     Comments       Blanks
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
 Autoconf                9           45           36            0            9
 BASH                   32           98           34           32           32
 Batch                   7          343          289            3           51
 C                      35        4,264        2,477        1,053          734
 C Header               46        3,370        2,351          485          534
 C++                    13          611          462           40          109
 CSS                     6          493          480           12            1
 Cython                  1           16            7            5            4
 Dockerfile              3          215           95          100           20
 Forge Config            2           38           38            0            0
 FORTRAN Modern          2          201          164            0           37
 Go                      2          140          118            0           22
 INI                     1            6            6            0            0
 JavaScript              2            4            4            0            0
 JSON                   79       21,932       21,930            0            2
 Julia                   2          120          105            0           15
 M4                      2        1,069          927            0          142
 MATLAB                155        6,266        4,650        1,017          599
 Makefile               70        1,322          926           79          317
 Python                844       88,642       76,181        2,127       10,334
 R                       5          256          215            6           35
 ReStructuredText       21        1,046          705            0          341
 Shell                   9          158           91           38           29
 SQL                    22        8,027        7,823          118           86
 SVG                     6          968          883            1           84
 TeX Class              26       14,091       10,548        2,413        1,130
 TeX Definition          3          207          195           12            0
 TeX                   676      328,270      178,952        3,421      145,897
 Plain Text             66      182,314            0      180,122        2,192
 TOML                   15          469          405           10           54
 XML                     1            7            7            0            0
 YAML                   93       37,661       35,816        1,147          698
───────────────────────────────────────────────────────────────────────────────
 HTML                   32        2,626        2,231          322           73
 |- CSS                  6          123          122            0            1
 |- JavaScript          10          530          457           11           62
 (Total)                          3,279        2,810          333          136
───────────────────────────────────────────────────────────────────────────────
 Jupyter Notebooks      11          658          324          270           64
 |- Markdown             7          288            0          259           29
 |- Python              10          370          324           11           35
 (Total)                          1,316          648          540          128
───────────────────────────────────────────────────────────────────────────────
 Markdown              377       27,448            0       20,957        6,491
 |- C                    1            7            6            0            1
 |- C++                  2           78           63            2           13
 |- HTML                 2           66           66            0            0
 |- JSON                 2        1,096        1,096            0            0
 |- MATLAB               1           62           28           29            5
 |- Markdown             1           51            0           50            1
 |- Python              36        2,017        1,621           82          314
 |- R                    2          214          178           36            0
 |- Rust                 2          269          237            6           26
 |- Shell               23        1,027          979            0           48
 |- SQL                  1            2            2            0            0
 |- TeX                  2           42           35            0            7
 |- TOML                 1           13           11            0            2
 |- XML                  1            8            8            0            0
 |- YAML                 7          263          234           17           12
 (Total)                         32,663        4,564       21,179        6,920
───────────────────────────────────────────────────────────────────────────────
 Rust                  146       11,378        9,824          355        1,199
 |- Markdown             2        2,891           26        2,177          688
 (Total)                         14,269        9,850        2,532        1,887
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
 Total               2,822      754,196      364,792      216,825      172,579
━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━
  </code></pre>
</details>
